OPERATION_NOT_SUPPORTED = 'operation is not supported..'
NO_ACTIVE_PROFILE = 'you have not logged in any of the profile or configure profiles'
ACCOUNT_API_NOT_SET = 'account/api_key is not set'
UNABLE_TO_CONNECT_OR_TIMED_OUT = '  Unable to make connection / time out. please chack the hostname or your internet ' \
                                 'connection.'

PROFILE_NOT_SET = "PROFILE: [ %s ] not configured"
PROFILE_NAME_IS_NONE = "PROFILE --name is not passed"
ID_IS_NULL = "--id/-i is mandatory while --operation/-op is fetch."
